aboutsummaryrefslogtreecommitdiff
path: root/include/asm-m32r/unistd.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asm-m32r/unistd.h')
-rw-r--r--include/asm-m32r/unistd.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/asm-m32r/unistd.h b/include/asm-m32r/unistd.h
index cc31790d807..5c6a9ac6cf1 100644
--- a/include/asm-m32r/unistd.h
+++ b/include/asm-m32r/unistd.h
@@ -3,8 +3,6 @@
/* $Id$ */
-#include <asm/syscall.h> /* SYSCALL_* */
-
/*
* This file contains the system call numbers.
*/
@@ -298,14 +296,17 @@
#ifdef __KERNEL__
#define NR_syscalls 285
/* user-visible error numbers are in the range -1 - -124: see
* <asm-m32r/errno.h>
*/
+#include <asm/syscall.h> /* SYSCALL_* */
+
#define __syscall_return(type, res) \
do { \
- if ((unsigned long)(res) >= (unsigned long)(-(124 + 1))) { \
+ if ((unsigned long)(res) >= (unsigned long)(-MAX_ERRNO)) { \
/* Avoid using "res" which is declared to be in register r0; \
errno might expand to a function call and clobber it. */ \
int __err = -(res); \
@@ -298,14 +296,17 @@
#ifdef __KERNEL__
#define NR_syscalls 285
+#include <linux/err.h>
-/* user-visible error numbers are in the range -1 - -124: see
+/* user-visible error numbers are in the range -1 - -MAX_ERRNO: see
* <asm-m32r/errno.h>
*/